# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/release_channel_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import constants_pb2 as prodvana_dot_common__config_dot_constants__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import maturity_pb2 as prodvana_dot_common__config_dot_maturity__pb2
from prodvana.proto.prodvana.labels import labels_pb2 as prodvana_dot_labels_dot_labels__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.prodvana.protection import attachments_pb2 as prodvana_dot_protection_dot_attachments__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2
from prodvana.proto.prodvana.workflow import integration_config_pb2 as prodvana_dot_workflow_dot_integration__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5prodvana/release_channel/release_channel_config.proto\x12\x18prodvana.release_channel\x1a&prodvana/common_config/constants.proto\x1a prodvana/common_config/env.proto\x1a%prodvana/common_config/maturity.proto\x1a\x1cprodvana/labels/labels.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a%prodvana/protection/attachments.proto\x1a\'prodvana/runtimes/runtimes_config.proto\x1a*prodvana/workflow/integration_config.proto\x1a\x17validate/validate.proto\"\xcd\x01\n\x06Policy\x12n\n\x0b\x64\x65\x66\x61ult_env\x18\x01 \x03(\x0b\x32\x30.prodvana.release_channel.Policy.DefaultEnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x1aS\n\x0f\x44\x65\x66\x61ultEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"\xf5\x05\n\x14ReleaseChannelConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\r\n\x05group\x18\x0c \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x03\x12\x32\n\x08maturity\x18\x03 \x01(\x0e\x32 .prodvana.common_config.Maturity\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .prodvana.release_channel.Policy\x12G\n\x08runtimes\x18\x05 \x03(\x0b\x32\x35.prodvana.release_channel.ReleaseChannelRuntimeConfig\x12@\n\x12\x64\x65ploy_annotations\x18\x06 \x01(\x0b\x32$.prodvana.workflow.AnnotationsConfig\x12=\n\rpreconditions\x18\x07 \x03(\x0b\x32&.prodvana.release_channel.Precondition\x12\x44\n\x0bprotections\x18\x08 \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12P\n\x17\x63onvergence_protections\x18\t \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12U\n\x1cservice_instance_protections\x18\x0b \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12\x33\n\tconstants\x18\n \x03(\x0b\x32 .prodvana.common_config.Constant\x12\x30\n\x06labels\x18\r \x03(\x0b\x32 .prodvana.labels.LabelDefinition\"\xdb\x05\n\x0cPrecondition\x12]\n\x16release_channel_stable\x18\x01 \x01(\x0b\x32;.prodvana.release_channel.Precondition.ReleaseChannelStableH\x00\x12P\n\x0fmanual_approval\x18\x02 \x01(\x0b\x32\x35.prodvana.release_channel.Precondition.ManualApprovalH\x00\x12H\n\x0b\x63ustom_task\x18\x03 \x01(\x0b\x32\x31.prodvana.release_channel.Precondition.CustomTaskH\x00\x12]\n\x16shared_manual_approval\x18\x05 \x01(\x0b\x32;.prodvana.release_channel.Precondition.SharedManualApprovalH\x00\x1a\x7f\n\x14ReleaseChannelStable\x12\x19\n\x0frelease_channel\x18\x01 \x01(\tH\x00\x12\x12\n\x08selector\x18\x03 \x01(\tH\x00\x12\x13\n\x0b\x61llow_empty\x18\x04 \x01(\x08\x42\x13\n\x0cstable_oneof\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03R\x08\x64uration\x1aI\n\x0eManualApproval\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x65very_action\x18\x03 \x01(\x08\x1aT\n\nCustomTask\x12\x11\n\ttask_name\x18\x01 \x01(\t\x12\x33\n\x0b\x63ustom_task\x18\x02 \x01(\x0b\x32\x1e.prodvana.pipelines.CustomTask\x1a-\n\x14SharedManualApproval\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x0e\n\x0cpreconditionJ\x04\x08\x04\x10\x05R\nprotection\"\xb9\x02\n\x1bReleaseChannelRuntimeConfig\x12<\n\x07runtime\x18\x02 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\x04name\x18\x03 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12S\n\x17\x63ontainer_orchestration\x18\x01 \x01(\x0b\x32\x30.prodvana.runtimes.ContainerOrchestrationRuntimeH\x00\x12=\n\x04type\x18\x04 \x01(\x0e\x32/.prodvana.release_channel.RuntimeConnectionTypeB\x0c\n\ncapability\"\xe3\x01\n\"ReleaseChannelGroupGeneratorConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12!\n\x10runtime_selector\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61llow_empty\x18\x03 \x01(\x08\x12J\n\x08template\x18\x04 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfigB\x08\xfa\x42\x05\x8a\x01\x02\x08\x01*V\n\x15RuntimeConnectionType\x12\x16\n\x12UNKNOWN_CONNECTION\x10\x00\x12\x16\n\x12LONG_LIVED_COMPUTE\x10\x01\x12\r\n\tEXTENSION\x10\x02\x42TZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release_channel.release_channel_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _POLICY_DEFAULTENVENTRY._options = None
  _POLICY_DEFAULTENVENTRY._serialized_options = b'8\001'
  _POLICY.fields_by_name['default_env']._options = None
  _POLICY.fields_by_name['default_env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _RELEASECHANNELCONFIG.fields_by_name['name']._options = None
  _RELEASECHANNELCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PRECONDITION_RELEASECHANNELSTABLE.oneofs_by_name['stable_oneof']._options = None
  _PRECONDITION_RELEASECHANNELSTABLE.oneofs_by_name['stable_oneof']._serialized_options = b'\370B\001'
  _PRECONDITION_SHAREDMANUALAPPROVAL.fields_by_name['name']._options = None
  _PRECONDITION_SHAREDMANUALAPPROVAL.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['runtime']._options = None
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['runtime']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['name']._options = None
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['name']._options = None
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['runtime_selector']._options = None
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['runtime_selector']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['template']._options = None
  _RELEASECHANNELGROUPGENERATORCONFIG.fields_by_name['template']._serialized_options = b'\372B\005\212\001\002\010\001'
  _globals['_RUNTIMECONNECTIONTYPE']._serialized_start=2659
  _globals['_RUNTIMECONNECTIONTYPE']._serialized_end=2745
  _globals['_POLICY']._serialized_start=412
  _globals['_POLICY']._serialized_end=617
  _globals['_POLICY_DEFAULTENVENTRY']._serialized_start=534
  _globals['_POLICY_DEFAULTENVENTRY']._serialized_end=617
  _globals['_RELEASECHANNELCONFIG']._serialized_start=620
  _globals['_RELEASECHANNELCONFIG']._serialized_end=1377
  _globals['_PRECONDITION']._serialized_start=1380
  _globals['_PRECONDITION']._serialized_end=2111
  _globals['_PRECONDITION_RELEASECHANNELSTABLE']._serialized_start=1742
  _globals['_PRECONDITION_RELEASECHANNELSTABLE']._serialized_end=1869
  _globals['_PRECONDITION_MANUALAPPROVAL']._serialized_start=1871
  _globals['_PRECONDITION_MANUALAPPROVAL']._serialized_end=1944
  _globals['_PRECONDITION_CUSTOMTASK']._serialized_start=1946
  _globals['_PRECONDITION_CUSTOMTASK']._serialized_end=2030
  _globals['_PRECONDITION_SHAREDMANUALAPPROVAL']._serialized_start=2032
  _globals['_PRECONDITION_SHAREDMANUALAPPROVAL']._serialized_end=2077
  _globals['_RELEASECHANNELRUNTIMECONFIG']._serialized_start=2114
  _globals['_RELEASECHANNELRUNTIMECONFIG']._serialized_end=2427
  _globals['_RELEASECHANNELGROUPGENERATORCONFIG']._serialized_start=2430
  _globals['_RELEASECHANNELGROUPGENERATORCONFIG']._serialized_end=2657
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery/delivery_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/delivery/delivery_config.proto\x12\x11prodvana.delivery\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\"_\n\x0e\x43\x61naryProgress\x12 \n\rcanary_weight\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x64(\x00\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"h\n\x0e\x44\x65liveryConfig\x12:\n\x0f\x63\x61nary_progress\x18\x01 \x03(\x0b\x32!.prodvana.delivery.CanaryProgress\x12\x1a\n\x12\x61nalysis_templates\x18\x02 \x03(\tBMZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/deliveryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery.delivery_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery'
  _CANARYPROGRESS.fields_by_name['canary_weight']._options = None
  _CANARYPROGRESS.fields_by_name['canary_weight']._serialized_options = b'\372B\006\032\004\030d(\000'
  _globals['_CANARYPROGRESS']._serialized_start=119
  _globals['_CANARYPROGRESS']._serialized_end=214
  _globals['_DELIVERYCONFIG']._serialized_start=216
  _globals['_DELIVERYCONFIG']._serialized_end=320
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.common_config.constants_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.maturity_pb2
import prodvana.proto.prodvana.labels.labels_pb2
import prodvana.proto.prodvana.pipelines.pipelines_pb2
import prodvana.proto.prodvana.protection.attachments_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RuntimeConnectionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RuntimeConnectionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RuntimeConnectionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_CONNECTION: _RuntimeConnectionType.ValueType  # 0
    LONG_LIVED_COMPUTE: _RuntimeConnectionType.ValueType  # 1
    EXTENSION: _RuntimeConnectionType.ValueType  # 2

class RuntimeConnectionType(_RuntimeConnectionType, metaclass=_RuntimeConnectionTypeEnumTypeWrapper): ...

UNKNOWN_CONNECTION: RuntimeConnectionType.ValueType  # 0
LONG_LIVED_COMPUTE: RuntimeConnectionType.ValueType  # 1
EXTENSION: RuntimeConnectionType.ValueType  # 2
global___RuntimeConnectionType = RuntimeConnectionType

class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class DefaultEnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_ENV_FIELD_NUMBER: builtins.int
    @property
    def default_env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    def __init__(
        self,
        *,
        default_env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_env", b"default_env"]) -> None: ...

global___Policy = Policy

class ReleaseChannelConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    MATURITY_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    RUNTIMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRECONDITIONS_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """intentionally does not reference cluster - this allows us to copy release channels across clusters via the same config"""
    group: builtins.str
    """if specified, this release channel is part of a group. This can affect how release channels are rendered on the Prodvana web interface."""
    order: builtins.int
    """deprecated"""
    maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType
    """deprecated"""
    @property
    def policy(self) -> global___Policy: ...
    @property
    def runtimes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReleaseChannelRuntimeConfig]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def preconditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Precondition]: ...
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def convergence_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def service_instance_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]:
        """protections that all service instances in this release channel should get"""
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        group: builtins.str = ...,
        order: builtins.int = ...,
        maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType = ...,
        policy: global___Policy | None = ...,
        runtimes: collections.abc.Iterable[global___ReleaseChannelRuntimeConfig] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        preconditions: collections.abc.Iterable[global___Precondition] | None = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        convergence_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        service_instance_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        labels: collections.abc.Iterable[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deploy_annotations", b"deploy_annotations", "policy", b"policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["constants", b"constants", "convergence_protections", b"convergence_protections", "deploy_annotations", b"deploy_annotations", "group", b"group", "labels", b"labels", "maturity", b"maturity", "name", b"name", "order", b"order", "policy", b"policy", "preconditions", b"preconditions", "protections", b"protections", "runtimes", b"runtimes", "service_instance_protections", b"service_instance_protections"]) -> None: ...

global___ReleaseChannelConfig = ReleaseChannelConfig

class Precondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ReleaseChannelStable(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
        SELECTOR_FIELD_NUMBER: builtins.int
        ALLOW_EMPTY_FIELD_NUMBER: builtins.int
        release_channel: builtins.str
        selector: builtins.str
        allow_empty: builtins.bool
        """if selector is used, allow selector to return an empty list of release channels"""
        def __init__(
            self,
            *,
            release_channel: builtins.str = ...,
            selector: builtins.str = ...,
            allow_empty: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel", "selector", b"selector", "stable_oneof", b"stable_oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["allow_empty", b"allow_empty", "release_channel", b"release_channel", "selector", b"selector", "stable_oneof", b"stable_oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["stable_oneof", b"stable_oneof"]) -> typing_extensions.Literal["release_channel", "selector"] | None: ...

    class ManualApproval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        DESCRIPTION_FIELD_NUMBER: builtins.int
        EVERY_ACTION_FIELD_NUMBER: builtins.int
        name: builtins.str
        description: builtins.str
        every_action: builtins.bool
        """request approval on every apply action, not just the first.
        only works for runtime extensions, will do nothing for kubernetes services.
        """
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            description: builtins.str = ...,
            every_action: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "every_action", b"every_action", "name", b"name"]) -> None: ...

    class CustomTask(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TASK_NAME_FIELD_NUMBER: builtins.int
        CUSTOM_TASK_FIELD_NUMBER: builtins.int
        task_name: builtins.str
        @property
        def custom_task(self) -> prodvana.proto.prodvana.pipelines.pipelines_pb2.CustomTask: ...
        def __init__(
            self,
            *,
            task_name: builtins.str = ...,
            custom_task: prodvana.proto.prodvana.pipelines.pipelines_pb2.CustomTask | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "task_name", b"task_name"]) -> None: ...

    class SharedManualApproval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        name: builtins.str
        def __init__(
            self,
            *,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

    RELEASE_CHANNEL_STABLE_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CUSTOM_TASK_FIELD_NUMBER: builtins.int
    SHARED_MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    @property
    def release_channel_stable(self) -> global___Precondition.ReleaseChannelStable: ...
    @property
    def manual_approval(self) -> global___Precondition.ManualApproval: ...
    @property
    def custom_task(self) -> global___Precondition.CustomTask: ...
    @property
    def shared_manual_approval(self) -> global___Precondition.SharedManualApproval: ...
    def __init__(
        self,
        *,
        release_channel_stable: global___Precondition.ReleaseChannelStable | None = ...,
        manual_approval: global___Precondition.ManualApproval | None = ...,
        custom_task: global___Precondition.CustomTask | None = ...,
        shared_manual_approval: global___Precondition.SharedManualApproval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval", b"manual_approval", "precondition", b"precondition", "release_channel_stable", b"release_channel_stable", "shared_manual_approval", b"shared_manual_approval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval", b"manual_approval", "precondition", b"precondition", "release_channel_stable", b"release_channel_stable", "shared_manual_approval", b"shared_manual_approval"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["precondition", b"precondition"]) -> typing_extensions.Literal["release_channel_stable", "manual_approval", "custom_task", "shared_manual_approval"] | None: ...

global___Precondition = Precondition

class ReleaseChannelRuntimeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTAINER_ORCHESTRATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    name: builtins.str
    """Optional identifier for this runtime connection within this release channel,
    useful if the release channel has multiple runtimes of the same type.
    Defaults to the value of `runtime``.
    """
    @property
    def container_orchestration(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.ContainerOrchestrationRuntime: ...
    type: global___RuntimeConnectionType.ValueType
    """set internally by prodvana, overridden even if set manually."""
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
        name: builtins.str = ...,
        container_orchestration: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.ContainerOrchestrationRuntime | None = ...,
        type: global___RuntimeConnectionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capability", b"capability", "container_orchestration", b"container_orchestration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capability", b"capability", "container_orchestration", b"container_orchestration", "name", b"name", "runtime", b"runtime", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["capability", b"capability"]) -> typing_extensions.Literal["container_orchestration"] | None: ...

global___ReleaseChannelRuntimeConfig = ReleaseChannelRuntimeConfig

class ReleaseChannelGroupGeneratorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RUNTIME_SELECTOR_FIELD_NUMBER: builtins.int
    ALLOW_EMPTY_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    name: builtins.str
    runtime_selector: builtins.str
    """label selector for runtimes to generate release channels for.
    One release channel will be generated for each runtime that matches this selector.
    The selector will automatically be intersected with "@type=runtime".
    """
    allow_empty: builtins.bool
    """By default, if the runtime selector returns an empty list of runtimes, Prodvana will error out.
    Set allow_empty to true to explicitly allow the selector to return an empty list.
    """
    @property
    def template(self) -> global___ReleaseChannelConfig:
        """optionally customize how the release channel will be generated.
        Template variables .Builtins.Group an d.Builtins.Runtime are available.
        Any value specified here will be merged with:
        name: {{.Builtins.Group}}-{{.Builtins.Runtime.Name}}
        group: {{.Builtins.Group}}
        runtimes:
        - runtime: {{Builtins.Runtime.Name}}
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        runtime_selector: builtins.str = ...,
        allow_empty: builtins.bool = ...,
        template: global___ReleaseChannelConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_empty", b"allow_empty", "name", b"name", "runtime_selector", b"runtime_selector", "template", b"template"]) -> None: ...

global___ReleaseChannelGroupGeneratorConfig = ReleaseChannelGroupGeneratorConfig



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.desired_state import manager_pb2 as prodvana_dot_desired__state_dot_manager__pb2


class DesiredStateManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetDesiredState = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/SetDesiredState',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateResp.FromString,
                )
        self.PreviewEntityGraph = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/PreviewEntityGraph',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.PreviewEntityGraphResp.FromString,
                )
        self.GetServiceDesiredStateConvergenceSummary = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetServiceDesiredStateConvergenceSummary',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryResp.FromString,
                )
        self.GetServiceLatestDesiredStateId = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetServiceLatestDesiredStateId',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdResp.FromString,
                )
        self.GetServiceLastConvergedStates = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetServiceLastConvergedStates',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateResp.FromString,
                )
        self.GetServiceDesiredStateHistory = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetServiceDesiredStateHistory',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryResp.FromString,
                )
        self.GetDesiredState = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetDesiredState',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateResp.FromString,
                )
        self.GetDesiredStateGraph = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetDesiredStateGraph',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphResp.FromString,
                )
        self.GetDesiredStateConvergenceSummary = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/GetDesiredStateConvergenceSummary',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceSummaryResp.FromString,
                )
        self.ValidateDesiredState = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/ValidateDesiredState',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateResp.FromString,
                )
        self.SetManualApproval = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/SetManualApproval',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalResp.FromString,
                )
        self.PromoteDelivery = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/PromoteDelivery',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryResp.FromString,
                )
        self.BypassProtection = channel.unary_unary(
                '/prodvana.desired_state.DesiredStateManager/BypassProtection',
                request_serializer=prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionReq.SerializeToString,
                response_deserializer=prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionResp.FromString,
                )


class DesiredStateManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetDesiredState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewEntityGraph(self, request, context):
        """validate a SetDesiredState call and return a preview entity graph
        TODO(naphat) delete ValidateDesiredState and replace with this
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceDesiredStateConvergenceSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceLatestDesiredStateId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceLastConvergedStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServiceDesiredStateHistory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDesiredState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDesiredStateGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDesiredStateConvergenceSummary(self, request, context):
        """Get the convergence summary for a desired state id.
        If the desired state id is pending, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
        The status will be set to PENDING_SET_DESIRED_STATE.
        If the desired state id was pending and failed to be set, the returned summary will not have the entity_graph set but will have pending_set_desired_state set.
        The status will be set to FAILED.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDesiredState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetManualApproval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PromoteDelivery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BypassProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DesiredStateManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetDesiredState': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDesiredState,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateResp.SerializeToString,
            ),
            'PreviewEntityGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewEntityGraph,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.PreviewEntityGraphResp.SerializeToString,
            ),
            'GetServiceDesiredStateConvergenceSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceDesiredStateConvergenceSummary,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryResp.SerializeToString,
            ),
            'GetServiceLatestDesiredStateId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceLatestDesiredStateId,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdResp.SerializeToString,
            ),
            'GetServiceLastConvergedStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceLastConvergedStates,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateResp.SerializeToString,
            ),
            'GetServiceDesiredStateHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServiceDesiredStateHistory,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryResp.SerializeToString,
            ),
            'GetDesiredState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDesiredState,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateResp.SerializeToString,
            ),
            'GetDesiredStateGraph': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDesiredStateGraph,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphResp.SerializeToString,
            ),
            'GetDesiredStateConvergenceSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDesiredStateConvergenceSummary,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceSummaryResp.SerializeToString,
            ),
            'ValidateDesiredState': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDesiredState,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateResp.SerializeToString,
            ),
            'SetManualApproval': grpc.unary_unary_rpc_method_handler(
                    servicer.SetManualApproval,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalResp.SerializeToString,
            ),
            'PromoteDelivery': grpc.unary_unary_rpc_method_handler(
                    servicer.PromoteDelivery,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryResp.SerializeToString,
            ),
            'BypassProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.BypassProtection,
                    request_deserializer=prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionReq.FromString,
                    response_serializer=prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.desired_state.DesiredStateManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DesiredStateManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetDesiredState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/SetDesiredState',
            prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewEntityGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/PreviewEntityGraph',
            prodvana_dot_desired__state_dot_manager__pb2.SetDesiredStateReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.PreviewEntityGraphResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceDesiredStateConvergenceSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetServiceDesiredStateConvergenceSummary',
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateConvergenceSummaryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceLatestDesiredStateId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetServiceLatestDesiredStateId',
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceLatestDesiredStateIdResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceLastConvergedStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetServiceLastConvergedStates',
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceLastConvergedStateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServiceDesiredStateHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetServiceDesiredStateHistory',
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetServiceDesiredStateHistoryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDesiredState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetDesiredState',
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDesiredStateGraph(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetDesiredStateGraph',
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateGraphResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDesiredStateConvergenceSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/GetDesiredStateConvergenceSummary',
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.GetDesiredStateConvergenceSummaryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateDesiredState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/ValidateDesiredState',
            prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.ValidateDesiredStateResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetManualApproval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/SetManualApproval',
            prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.SetManualApprovalResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PromoteDelivery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/PromoteDelivery',
            prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.PromoteDeliveryResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BypassProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.desired_state.DesiredStateManager/BypassProtection',
            prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionReq.SerializeToString,
            prodvana_dot_desired__state_dot_manager__pb2.BypassProtectionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/meta.proto\x12\x16prodvana.common_config\x1a\x1aprodvana/object/meta.proto\"\x89\x01\n\x19ServiceInstanceObjectMeta\x12\x31\n\x0cservice_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x39\n\x14release_channel_meta\x18\x02 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x15PipelineRunObjectMeta\x12\x32\n\rpipeline_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x10\n\x08run_name\x18\x02 \x01(\tBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.meta_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _globals['_SERVICEINSTANCEOBJECTMETA']._serialized_start=90
  _globals['_SERVICEINSTANCEOBJECTMETA']._serialized_end=227
  _globals['_PIPELINERUNOBJECTMETA']._serialized_start=229
  _globals['_PIPELINERUNOBJECTMETA']._serialized_end=322
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pipelines/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprodvana/pipelines/object.proto\x12\x12prodvana.pipelines\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!prodvana/common_config/meta.proto\"\xa6\x01\n\x10PipelineRunState\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05state\x18\x03 \x01(\t\x12\x10\n\x08terminal\x18\x04 \x01(\x08\"\x7f\n\x0bPipelineRun\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.prodvana.common_config.PipelineRunObjectMeta\x12\x33\n\x05state\x18\x03 \x01(\x0b\x32$.prodvana.pipelines.PipelineRunStateBNZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelinesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.pipelines.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelines'
  _globals['_PIPELINERUNSTATE']._serialized_start=124
  _globals['_PIPELINERUNSTATE']._serialized_end=290
  _globals['_PIPELINERUN']._serialized_start=292
  _globals['_PIPELINERUN']._serialized_end=419
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/auth/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18prodvana/auth/auth.proto\x12\rprodvana.auth\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1a\n\tAuthToken\x12\r\n\x05token\x18\x01 \x01(\t\"\xa0\x01\n\x0c\x41piTokenInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x11\x65xpires_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\\\n\x0b\x41uthContext\x12,\n\nauth_token\x18\x01 \x01(\x0b\x32\x18.prodvana.auth.AuthToken\x12\x11\n\tapi_token\x18\x02 \x01(\t\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x01(\t\"\xfe\x02\n\x07Session\x12\x36\n\x08\x63ontexts\x18\x03 \x03(\x0b\x32$.prodvana.auth.Session.ContextsEntry\x12\x17\n\x0f\x63urrent_context\x18\x04 \x01(\t\x12\x41\n\x0e\x61\x64min_contexts\x18\x05 \x03(\x0b\x32).prodvana.auth.Session.AdminContextsEntry\x12\x1d\n\x15\x63urrent_admin_context\x18\x06 \x01(\t\x1aK\n\rContextsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.prodvana.auth.AuthContext:\x02\x38\x01\x1aP\n\x12\x41\x64minContextsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.prodvana.auth.AuthContext:\x02\x38\x01J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\nauth_tokenR\tapi_tokenBIZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.auth.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/auth'
  _SESSION_CONTEXTSENTRY._options = None
  _SESSION_CONTEXTSENTRY._serialized_options = b'8\001'
  _SESSION_ADMINCONTEXTSENTRY._options = None
  _SESSION_ADMINCONTEXTSENTRY._serialized_options = b'8\001'
  _globals['_AUTHTOKEN']._serialized_start=76
  _globals['_AUTHTOKEN']._serialized_end=102
  _globals['_APITOKENINFO']._serialized_start=105
  _globals['_APITOKENINFO']._serialized_end=265
  _globals['_AUTHCONTEXT']._serialized_start=267
  _globals['_AUTHCONTEXT']._serialized_end=359
  _globals['_SESSION']._serialized_start=362
  _globals['_SESSION']._serialized_end=744
  _globals['_SESSION_CONTEXTSENTRY']._serialized_start=552
  _globals['_SESSION_CONTEXTSENTRY']._serialized_end=627
  _globals['_SESSION_ADMINCONTEXTSENTRY']._serialized_start=629
  _globals['_SESSION_ADMINCONTEXTSENTRY']._serialized_end=709
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.capability.capability_pb2
import prodvana.proto.prodvana.common_config.constants_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.helm_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.maturity_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.program_pb2
import prodvana.proto.prodvana.common_config.retry_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.delivery.delivery_config_pb2
import prodvana.proto.prodvana.delivery_extension.config_pb2
import prodvana.proto.prodvana.protection.attachments_pb2
import prodvana.proto.prodvana.protection.protection_reference_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.service.parameters_pb2
import prodvana.proto.prodvana.volumes.volumes_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReplicasConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    fixed: builtins.int
    """no validations, server side has defaults"""
    def __init__(
        self,
        *,
        fixed: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "fixed", b"fixed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "fixed", b"fixed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["fixed"] | None: ...

global___ReplicasConfig = ReplicasConfig

class MetricAnalysis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class SuccessRateConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MIN_THRESHOLD_PERCENT_FIELD_NUMBER: builtins.int
        min_threshold_percent: builtins.float
        def __init__(
            self,
            *,
            min_threshold_percent: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["min_threshold_percent", b"min_threshold_percent"]) -> None: ...

    class LatencyConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_LATENCY_FIELD_NUMBER: builtins.int
        @property
        def max_latency(self) -> google.protobuf.duration_pb2.Duration: ...
        def __init__(
            self,
            *,
            max_latency: google.protobuf.duration_pb2.Duration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["max_latency", b"max_latency"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["max_latency", b"max_latency"]) -> None: ...

    SUCCESS_RATE_FIELD_NUMBER: builtins.int
    LATENCY_P95_FIELD_NUMBER: builtins.int
    @property
    def success_rate(self) -> global___MetricAnalysis.SuccessRateConfig: ...
    @property
    def latency_p95(self) -> global___MetricAnalysis.LatencyConfig: ...
    def __init__(
        self,
        *,
        success_rate: global___MetricAnalysis.SuccessRateConfig | None = ...,
        latency_p95: global___MetricAnalysis.LatencyConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["analysis_oneof", b"analysis_oneof", "latency_p95", b"latency_p95", "success_rate", b"success_rate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analysis_oneof", b"analysis_oneof", "latency_p95", b"latency_p95", "success_rate", b"success_rate"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["analysis_oneof", b"analysis_oneof"]) -> typing_extensions.Literal["success_rate", "latency_p95"] | None: ...

global___MetricAnalysis = MetricAnalysis

class ReleaseStrategyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDIVIDUAL_STAGE_DEADLINE_FIELD_NUMBER: builtins.int
    AUTOMATED_TESTING_DURATION_FIELD_NUMBER: builtins.int
    METRICS_ANALYSIS_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CHECK_INTERVAL_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def individual_stage_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """deadline in each stage before the push is rolled back. Includes the time it takes for pods to be healthy. Defaults to 10 minutes."""
    @property
    def automated_testing_duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration of the automated testing phase, before manual approval. Defaults to 30m."""
    @property
    def metrics_analysis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricAnalysis]: ...
    manual_approval: builtins.bool
    @property
    def check_interval(self) -> google.protobuf.duration_pb2.Duration:
        """advanced settings that do not typically need to be set. Exposed mainly for testing purposes.
        defaults to 30s
        """
    failure_threshold: builtins.int
    """defaults to 5"""
    def __init__(
        self,
        *,
        individual_stage_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        automated_testing_duration: google.protobuf.duration_pb2.Duration | None = ...,
        metrics_analysis: collections.abc.Iterable[global___MetricAnalysis] | None = ...,
        manual_approval: builtins.bool = ...,
        check_interval: google.protobuf.duration_pb2.Duration | None = ...,
        failure_threshold: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["automated_testing_duration", b"automated_testing_duration", "check_interval", b"check_interval", "individual_stage_deadline", b"individual_stage_deadline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automated_testing_duration", b"automated_testing_duration", "check_interval", b"check_interval", "failure_threshold", b"failure_threshold", "individual_stage_deadline", b"individual_stage_deadline", "manual_approval", b"manual_approval", "metrics_analysis", b"metrics_analysis"]) -> None: ...

global___ReleaseStrategyConfig = ReleaseStrategyConfig

class TLSSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_SECRET_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    raw_secret: builtins.str
    """Raw secret value to be used for user-editable YAML and RPC calls."""
    @property
    def secret(self) -> prodvana.proto.prodvana.common_config.env_pb2.Secret:
        """Externally stored secret."""
    def __init__(
        self,
        *,
        raw_secret: builtins.str = ...,
        secret: prodvana.proto.prodvana.common_config.env_pb2.Secret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret", b"secret", "tls_secret", b"tls_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret", b"secret", "tls_secret", b"tls_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["tls_secret", b"tls_secret"]) -> typing_extensions.Literal["raw_secret", "secret"] | None: ...

global___TLSSecret = TLSSecret

class TLSCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TLS_CERT_FIELD_NUMBER: builtins.int
    TLS_KEY_FIELD_NUMBER: builtins.int
    @property
    def tls_cert(self) -> global___TLSSecret: ...
    @property
    def tls_key(self) -> global___TLSSecret: ...
    def __init__(
        self,
        *,
        tls_cert: global___TLSSecret | None = ...,
        tls_key: global___TLSSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tls_cert", b"tls_cert", "tls_key", b"tls_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tls_cert", b"tls_cert", "tls_key", b"tls_key"]) -> None: ...

global___TLSCertificate = TLSCertificate

class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TLS_FIELD_NUMBER: builtins.int
    AWS_ACM_CERT_FIELD_NUMBER: builtins.int
    @property
    def tls(self) -> global___TLSCertificate: ...
    aws_acm_cert: builtins.str
    def __init__(
        self,
        *,
        tls: global___TLSCertificate | None = ...,
        aws_acm_cert: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_acm_cert", b"aws_acm_cert", "certificate", b"certificate", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_acm_cert", b"aws_acm_cert", "certificate", b"certificate", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["certificate", b"certificate"]) -> typing_extensions.Literal["tls", "aws_acm_cert"] | None: ...

global___Certificate = Certificate

class PerReleaseChannelConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    CUSTOM_HOSTNAMES_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    CERT_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    RUNTIME_CONNECTION_FIELD_NUMBER: builtins.int
    RUNTIME_EXTENSION_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    EXTERNAL_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    @property
    def custom_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.PerReleaseChannelProgramConfig]: ...
    @property
    def cert(self) -> global___Certificate: ...
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: Replace with delivery_extensions once its implemented."""
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    runtime_connection: builtins.str
    """which runtime connection to use in each release channel.
    optional if only one runtime makes sense for the service config.
    """
    @property
    def runtime_extension(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def external_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig:
        """deprecated, pass this as kubernetes_config instead"""
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """Additional env variables that are injected to the service.
        This can be useful for injecting and/or overriding env variables from release channel
        configs for Kubernetes and runtime extension configs.
        Not supported for helm configs.
        """
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        custom_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.PerReleaseChannelProgramConfig] | None = ...,
        cert: global___Certificate | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        delivery_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        runtime_connection: builtins.str = ...,
        runtime_extension: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        external_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cert", b"cert", "config_oneof", b"config_oneof", "delivery_config", b"delivery_config", "external_config", b"external_config", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "replicas", b"replicas", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert", b"cert", "config_oneof", b"config_oneof", "constants", b"constants", "custom_hostnames", b"custom_hostnames", "delivery_config", b"delivery_config", "delivery_extensions", b"delivery_extensions", "env", b"env", "external_config", b"external_config", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "protections", b"protections", "release_channel", b"release_channel", "replicas", b"replicas", "runtime_connection", b"runtime_connection", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["runtime_extension", "kubernetes_config", "external_config", "helm"] | None: ...

global___PerReleaseChannelConfig = PerReleaseChannelConfig

class CapabilityReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CapabilityReference = CapabilityReference

class CompiledCapabilityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPABILITY_FIELD_NUMBER: builtins.int
    @property
    def capability(self) -> prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig: ...
    def __init__(
        self,
        *,
        capability: prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capability", b"capability"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capability", b"capability"]) -> None: ...

global___CompiledCapabilityConfig = CompiledCapabilityConfig

class ProgramReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["name", b"name", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["name"] | None: ...

global___ProgramReference = ProgramReference

class TaskReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ref", b"ref", "release_channel", b"release_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ref", b"ref", "release_channel", b"release_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["release_channel"] | None: ...

global___TaskReference = TaskReference

class TaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRAM_FIELD_NUMBER: builtins.int
    BASE_PROGRAM_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    @property
    def program(self) -> prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig: ...
    @property
    def base_program(self) -> global___ProgramReference:
        """optional base program to take configs from. If specified, `program` field will act
        like an override instead.
        """
    @property
    def retry_config(self) -> prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig:
        """if not set, the task will not be retried once it starts executing once."""
    @property
    def ref(self) -> global___TaskReference:
        """Instead of defining a new task, reference an existing custom task and use that. This is meant
        to be used in conjunection with per_release_channel to allow multiple release channels to use
        a single custom task. If set, the program definition is ignored except for program name.
        """
    def __init__(
        self,
        *,
        program: prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig | None = ...,
        base_program: global___ProgramReference | None = ...,
        retry_config: prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig | None = ...,
        ref: global___TaskReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_program", b"base_program", "program", b"program", "ref", b"ref", "retry_config", b"retry_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_program", b"base_program", "program", b"program", "ref", b"ref", "retry_config", b"retry_config"]) -> None: ...

global___TaskConfig = TaskConfig

class ProtectionLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_FIELD_NUMBER: builtins.int
    ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def lifecycle(self) -> prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle: ...
    attachment_id: builtins.str
    def __init__(
        self,
        *,
        lifecycle: prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle | None = ...,
        attachment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_id", b"attachment_id", "lifecycle", b"lifecycle"]) -> None: ...

global___ProtectionLink = ProtectionLink

class DeliveryExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    @property
    def inlined(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig:
        """Inline definition of a delivery extension."""
    instance: builtins.str
    """A delivery instance defined in this service config."""
    @property
    def ref(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef:
        """Reference to a delivery extension defined externally."""
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    def __init__(
        self,
        *,
        inlined: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        instance: builtins.str = ...,
        ref: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef | None = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "instance", b"instance", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "instance", b"instance", "lifecycle", b"lifecycle", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["definition", b"definition"]) -> typing_extensions.Literal["inlined", "instance", "ref"] | None: ...

global___DeliveryExtensionConfig = DeliveryExtensionConfig

class DeliveryExtensionInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    @property
    def inlined(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig:
        """Inline definition of the delivery extension."""
    @property
    def ref(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef:
        """Reference to a delivery extension defined externally."""
    name: builtins.str
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    def __init__(
        self,
        *,
        inlined: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        ref: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef | None = ...,
        name: builtins.str = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "lifecycle", b"lifecycle", "name", b"name", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["definition", b"definition"]) -> typing_extensions.Literal["inlined", "ref"] | None: ...

global___DeliveryExtensionInstance = DeliveryExtensionInstance

class RuntimeSpecificConfig(google.protobuf.message.Message):
    """RuntimeSpecificConfig contains Service level configuration options that only make sense for a
    specific Runtime type. Configuration added here should only apply to a single Service; if the
    Runtime specific configuration relates to all services, it should be configured as at the
    Runtime cluster level (or as a runtime extension).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class K8SConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class ServiceAnnotationsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        SERVICE_ANNOTATIONS_FIELD_NUMBER: builtins.int
        @property
        def service_annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Annotations to add to the Kubernetes Service object"""
        def __init__(
            self,
            *,
            service_annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["service_annotations", b"service_annotations"]) -> None: ...

    K8S_FIELD_NUMBER: builtins.int
    @property
    def k8s(self) -> global___RuntimeSpecificConfig.K8SConfig: ...
    def __init__(
        self,
        *,
        k8s: global___RuntimeSpecificConfig.K8SConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_config", b"runtime_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_config", b"runtime_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["runtime_config", b"runtime_config"]) -> typing_extensions.Literal["k8s"] | None: ...

global___RuntimeSpecificConfig = RuntimeSpecificConfig

class RuntimeExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    def __init__(
        self,
        *,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter_values", b"parameter_values"]) -> None: ...

global___RuntimeExtensionConfig = RuntimeExtensionConfig

class AutoRollbackConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled"]) -> None: ...

global___AutoRollbackConfig = AutoRollbackConfig

class ServiceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ParametersAutogen:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ParametersAutogenEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ServiceConfig._ParametersAutogen.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ServiceConfig._ParametersAutogen.ValueType  # 0
        NONE: ServiceConfig._ParametersAutogen.ValueType  # 1
        """no autogen"""
        IMAGE: ServiceConfig._ParametersAutogen.ValueType  # 2
        """autogen one parameter per program for the image"""
        IMAGE_AND_REPLICAS: ServiceConfig._ParametersAutogen.ValueType  # 3
        """IMAGE + autogen a parameter for replicas count"""

    class ParametersAutogen(_ParametersAutogen, metaclass=_ParametersAutogenEnumTypeWrapper): ...
    UNKNOWN: ServiceConfig.ParametersAutogen.ValueType  # 0
    NONE: ServiceConfig.ParametersAutogen.ValueType  # 1
    """no autogen"""
    IMAGE: ServiceConfig.ParametersAutogen.ValueType  # 2
    """autogen one parameter per program for the image"""
    IMAGE_AND_REPLICAS: ServiceConfig.ParametersAutogen.ValueType  # 3
    """IMAGE + autogen a parameter for replicas count"""

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RELEASE_STRATEGY_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSION_INSTANCES_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    RUNTIME_CONNECTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_FIELD_NUMBER: builtins.int
    RUNTIME_EXTENSION_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    EXTERNAL_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    PARAMETERS_AUTOGEN_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    NO_CLEANUP_ON_DELETE_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ASYNC_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    name: builtins.str
    application: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    @property
    def release_strategy(self) -> global___ReleaseStrategyConfig: ...
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PerReleaseChannelConfig]: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CapabilityReference]:
        """deprecated"""
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: Replace with delivery_extensions"""
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def delivery_extension_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionInstance]: ...
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    runtime_connection: builtins.str
    """which runtime connection to use in each release channel.
    optional if only one runtime makes sense for the service config.
    """
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def parameter_values(self) -> prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues:
        """only valid to set in compiled configs by Prodvana"""
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def progress_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """how long to wait before marking deployment as failed"""
    @property
    def runtime_extension(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def external_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig:
        """deprecated, pass this as kubernetes_config instead"""
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    parameters_autogen: global___ServiceConfig.ParametersAutogen.ValueType
    """How to autogenerate parameters, defaults to IMAGE. Ignored for Kubernetes or Helm configs."""
    @property
    def auto_rollback(self) -> global___AutoRollbackConfig: ...
    no_cleanup_on_delete: builtins.bool
    """if set, do not attempt to delete the underlying runtime objects when deleting a service"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """Additional env variables that are injected to the service.
        This can be useful for injecting and/or overriding env variables from release channel
        configs for Kubernetes and runtime extension configs.
        Not supported for helm configs.
        """
    async_set_desired_state: builtins.bool
    """internal use"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        application: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        release_strategy: global___ReleaseStrategyConfig | None = ...,
        per_release_channel: collections.abc.Iterable[global___PerReleaseChannelConfig] | None = ...,
        capabilities: collections.abc.Iterable[global___CapabilityReference] | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        delivery_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        delivery_extension_instances: collections.abc.Iterable[global___DeliveryExtensionInstance] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        runtime_connection: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        parameter_values: prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        progress_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        runtime_extension: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        external_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        parameters_autogen: global___ServiceConfig.ParametersAutogen.ValueType = ...,
        auto_rollback: global___AutoRollbackConfig | None = ...,
        no_cleanup_on_delete: builtins.bool = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        async_set_desired_state: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_rollback", b"auto_rollback", "config_oneof", b"config_oneof", "delivery_config", b"delivery_config", "deploy_annotations", b"deploy_annotations", "external_config", b"external_config", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "parameter_values", b"parameter_values", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "async_set_desired_state", b"async_set_desired_state", "auto_rollback", b"auto_rollback", "capabilities", b"capabilities", "config_oneof", b"config_oneof", "constants", b"constants", "delivery_config", b"delivery_config", "delivery_extension_instances", b"delivery_extension_instances", "delivery_extensions", b"delivery_extensions", "deploy_annotations", b"deploy_annotations", "env", b"env", "external_config", b"external_config", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "name", b"name", "no_cleanup_on_delete", b"no_cleanup_on_delete", "parameter_values", b"parameter_values", "parameters", b"parameters", "parameters_autogen", b"parameters_autogen", "per_release_channel", b"per_release_channel", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime_connection", b"runtime_connection", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["runtime_extension", "kubernetes_config", "external_config", "helm"] | None: ...

global___ServiceConfig = ServiceConfig

class CompiledServiceInstanceConfig(google.protobuf.message.Message):
    """a compiled version of ServiceConfig specific to a service instance, with release-channel configs applied"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SERVICE_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    MATURITY_FIELD_NUMBER: builtins.int
    RELEASE_STRATEGY_FIELD_NUMBER: builtins.int
    CUSTOM_HOSTNAMES_FIELD_NUMBER: builtins.int
    CERT_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSION_INSTANCES_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_FIELD_NUMBER: builtins.int
    RUNTIME_EXTENSION_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    NO_CLEANUP_ON_DELETE_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    service: builtins.str
    application: builtins.str
    release_channel: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType
    @property
    def release_strategy(self) -> global___ReleaseStrategyConfig: ...
    @property
    def custom_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def cert(self) -> global___Certificate: ...
    @property
    def runtime(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompiledCapabilityConfig]: ...
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: Replace with delivery_extensions once its implemented."""
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def delivery_extension_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionInstance]: ...
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def progress_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """how long to wait before marking deployment as failed"""
    @property
    def runtime_extension(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """The compiled environment for this instance's context, e.g.  Release Channel.
        This is used to inject these values into external configs.
        """
    no_cleanup_on_delete: builtins.bool
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType = ...,
        release_strategy: global___ReleaseStrategyConfig | None = ...,
        custom_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        cert: global___Certificate | None = ...,
        runtime: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        capabilities: collections.abc.Iterable[global___CompiledCapabilityConfig] | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        delivery_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        delivery_extension_instances: collections.abc.Iterable[global___DeliveryExtensionInstance] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        progress_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        runtime_extension: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        no_cleanup_on_delete: builtins.bool = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cert", b"cert", "config_oneof", b"config_oneof", "delivery_config", b"delivery_config", "deploy_annotations", b"deploy_annotations", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime", b"runtime", "runtime_execution", b"runtime_execution", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "capabilities", b"capabilities", "cert", b"cert", "config_oneof", b"config_oneof", "constants", b"constants", "custom_hostnames", b"custom_hostnames", "delivery_config", b"delivery_config", "delivery_extension_instances", b"delivery_extension_instances", "delivery_extensions", b"delivery_extensions", "deploy_annotations", b"deploy_annotations", "env", b"env", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "maturity", b"maturity", "no_cleanup_on_delete", b"no_cleanup_on_delete", "parameter_values", b"parameter_values", "parameters", b"parameters", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "progress_deadline", b"progress_deadline", "protections", b"protections", "release_channel", b"release_channel", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime", b"runtime", "runtime_execution", b"runtime_execution", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific", "service", b"service", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["runtime_extension", "kubernetes_config", "helm"] | None: ...

global___CompiledServiceInstanceConfig = CompiledServiceInstanceConfig

class CompiledJobConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    release_channel: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def runtime(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    def __init__(
        self,
        *,
        name_prefix: builtins.str = ...,
        release_channel: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        runtime: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime", b"runtime", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name_prefix", b"name_prefix", "programs", b"programs", "release_channel", b"release_channel", "runtime", b"runtime", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledJobConfig = CompiledJobConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AlertingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class PagerDuty(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SERVICE_FIELD_NUMBER: builtins.int
        service: builtins.str
        def __init__(
            self,
            *,
            service: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["service", b"service"]) -> None: ...

    PAGERDUTY_FIELD_NUMBER: builtins.int
    @property
    def pagerduty(self) -> global___AlertingConfig.PagerDuty: ...
    def __init__(
        self,
        *,
        pagerduty: global___AlertingConfig.PagerDuty | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagerduty", b"pagerduty"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagerduty", b"pagerduty"]) -> None: ...

global___AlertingConfig = AlertingConfig

class AnnotationsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Honeycomb(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENVIRONMENT_FIELD_NUMBER: builtins.int
        DATASET_FIELD_NUMBER: builtins.int
        environment: builtins.str
        dataset: builtins.str
        def __init__(
            self,
            *,
            environment: builtins.str = ...,
            dataset: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["dataset", b"dataset", "environment", b"environment"]) -> None: ...

    HONEYCOMB_FIELD_NUMBER: builtins.int
    @property
    def honeycomb(self) -> global___AnnotationsConfig.Honeycomb: ...
    def __init__(
        self,
        *,
        honeycomb: global___AnnotationsConfig.Honeycomb | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["honeycomb", b"honeycomb"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["honeycomb", b"honeycomb"]) -> None: ...

global___AnnotationsConfig = AnnotationsConfig

class TokenConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_SECRET_KEY_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_VERSION_FIELD_NUMBER: builtins.int
    token_secret_key: builtins.str
    token_secret_version: builtins.str
    def __init__(
        self,
        *,
        token_secret_key: builtins.str = ...,
        token_secret_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_secret_key", b"token_secret_key", "token_secret_version", b"token_secret_version"]) -> None: ...

global___TokenConfig = TokenConfig

class IntegrationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_CONFIG_FIELD_NUMBER: builtins.int
    PAGERDUTY_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def slack_config(self) -> global___TokenConfig: ...
    @property
    def pagerduty_config(self) -> global___TokenConfig: ...
    def __init__(
        self,
        *,
        slack_config: global___TokenConfig | None = ...,
        pagerduty_config: global___TokenConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "pagerduty_config", b"pagerduty_config", "slack_config", b"slack_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "pagerduty_config", b"pagerduty_config", "slack_config", b"slack_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["slack_config", "pagerduty_config"] | None: ...

global___IntegrationConfig = IntegrationConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/blobs/blobs_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/blobs/blobs_manager.proto\x12\x0eprodvana.blobs\x1a\x1cgoogle/api/annotations.proto\x1a\x17validate/validate.proto\"$\n\rGetCasBlobReq\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x1f\n\x0eGetCasBlobResp\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"!\n\x10UploadCasBlobReq\x12\r\n\x05\x62ytes\x18\x01 \x01(\x0c\"\x1f\n\x11UploadCasBlobResp\x12\n\n\x02id\x18\x01 \x01(\t2\xd5\x01\n\x0c\x42lobsManager\x12k\n\nGetCasBlob\x12\x1d.prodvana.blobs.GetCasBlobReq\x1a\x1e.prodvana.blobs.GetCasBlobResp\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/blobs/cas/{id=*}0\x01\x12X\n\rUploadCasBlob\x12 .prodvana.blobs.UploadCasBlobReq\x1a!.prodvana.blobs.UploadCasBlobResp\"\x00(\x01\x42JZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/blobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.blobs.blobs_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZHgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/blobs'
  _GETCASBLOBREQ.fields_by_name['id']._options = None
  _GETCASBLOBREQ.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _BLOBSMANAGER.methods_by_name['GetCasBlob']._options = None
  _BLOBSMANAGER.methods_by_name['GetCasBlob']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/blobs/cas/{id=*}'
  _globals['_GETCASBLOBREQ']._serialized_start=109
  _globals['_GETCASBLOBREQ']._serialized_end=145
  _globals['_GETCASBLOBRESP']._serialized_start=147
  _globals['_GETCASBLOBRESP']._serialized_end=178
  _globals['_UPLOADCASBLOBREQ']._serialized_start=180
  _globals['_UPLOADCASBLOBREQ']._serialized_end=213
  _globals['_UPLOADCASBLOBRESP']._serialized_start=215
  _globals['_UPLOADCASBLOBRESP']._serialized_end=246
  _globals['_BLOBSMANAGER']._serialized_start=249
  _globals['_BLOBSMANAGER']._serialized_end=462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.release import object_pb2 as prodvana_dot_release_dot_object__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/release/manager.proto\x12\x10prodvana.release\x1a\x1cgoogle/api/annotations.proto\x1a\x1aprodvana/object/meta.proto\x1a\x1dprodvana/release/object.proto\x1a\x17validate/validate.proto\"^\n\x10RecordReleaseReq\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.release.ReleaseConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0f\n\x07pending\x18\x02 \x01(\x08\">\n\x11RecordReleaseResp\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x16UpdateReleaseStatusReq\x12\x12\n\nrelease_id\x18\x01 \x01(\t\x12/\n\x06status\x18\x02 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"J\n\x17UpdateReleaseStatusResp\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.prodvana.release.ReleaseStatus\"\xb0\x02\n\x0fListReleasesReq\x12\x39\n\x07\x66ilters\x18\x01 \x03(\x0b\x32(.prodvana.release.ListReleasesReq.Filter\x12\x38\n\x06\x66ilter\x18\x02 \x01(\x0b\x32(.prodvana.release.ListReleasesReq.Filter\x12\x1b\n\x13starting_release_id\x18\x03 \x01(\t\x12\x19\n\x11\x65nding_release_id\x18\x04 \x01(\t\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x11\n\tpage_size\x18\x06 \x01(\x05\x1aI\n\x06\x46ilter\x12\x10\n\x08services\x18\x01 \x03(\t\x12\x18\n\x10release_channels\x18\x02 \x03(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"X\n\x10ListReleasesResp\x12+\n\x08releases\x18\x01 \x03(\x0b\x32\x19.prodvana.release.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xed\x03\n\x0eReleaseManager\x12q\n\rRecordRelease\x12\".prodvana.release.RecordReleaseReq\x1a#.prodvana.release.RecordReleaseResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/releases:\x01*\x12\x99\x01\n\x13UpdateReleaseStatus\x12(.prodvana.release.UpdateReleaseStatusReq\x1a).prodvana.release.UpdateReleaseStatusResp\"-\x82\xd3\xe4\x93\x02\'\"\"/v1/releases/{release_id=*}/status:\x01*\x12k\n\x0cListReleases\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/releases\x12_\n\x12ListReleasesStream\x12!.prodvana.release.ListReleasesReq\x1a\".prodvana.release.ListReleasesResp\"\x00\x30\x01\x42LZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/releaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release'
  _RECORDRELEASEREQ.fields_by_name['config']._options = None
  _RECORDRELEASEREQ.fields_by_name['config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _RELEASEMANAGER.methods_by_name['RecordRelease']._options = None
  _RELEASEMANAGER.methods_by_name['RecordRelease']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/releases:\001*'
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._options = None
  _RELEASEMANAGER.methods_by_name['UpdateReleaseStatus']._serialized_options = b'\202\323\344\223\002\'\"\"/v1/releases/{release_id=*}/status:\001*'
  _RELEASEMANAGER.methods_by_name['ListReleases']._options = None
  _RELEASEMANAGER.methods_by_name['ListReleases']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/releases'
  _globals['_RECORDRELEASEREQ']._serialized_start=166
  _globals['_RECORDRELEASEREQ']._serialized_end=260
  _globals['_RECORDRELEASERESP']._serialized_start=262
  _globals['_RECORDRELEASERESP']._serialized_end=324
  _globals['_UPDATERELEASESTATUSREQ']._serialized_start=326
  _globals['_UPDATERELEASESTATUSREQ']._serialized_end=419
  _globals['_UPDATERELEASESTATUSRESP']._serialized_start=421
  _globals['_UPDATERELEASESTATUSRESP']._serialized_end=495
  _globals['_LISTRELEASESREQ']._serialized_start=498
  _globals['_LISTRELEASESREQ']._serialized_end=802
  _globals['_LISTRELEASESREQ_FILTER']._serialized_start=729
  _globals['_LISTRELEASESREQ_FILTER']._serialized_end=802
  _globals['_LISTRELEASESRESP']._serialized_start=804
  _globals['_LISTRELEASESRESP']._serialized_end=892
  _globals['_RELEASEMANAGER']._serialized_start=895
  _globals['_RELEASEMANAGER']._serialized_end=1388
# @@protoc_insertion_point(module_scope)
